Struct mzdata::spectrum::SpectrumGroup

source ·
pub struct SpectrumGroup<C = CentroidPeak, D = DeconvolutedPeak, S = MultiLayerSpectrum<C, D>>{
    pub precursor: Option<S>,
    pub products: Vec<S>,
    /* private fields */
}
A pairing of an optional MS1 spectrum with all its associated MSn spectra.

Fields

precursor: Option<S>

The MS1 spectrum of a group. This may be absent when the source does not contain any MS1 spectra

products: Vec<S>

The collection of related MSn spectra. If MSn for n > 2 is used, all levels are present in this collection, though there is no ordering guarantee.

Implementations

source

impl<'a, C, D, S> SpectrumGroup<C, D, S>

source

pub fn iter(&'a self) -> SpectrumGroupIter<'a, C, D, S>