Elements of controlled vocabularies used to describe mass spectra and their components.
Directly maps to the usage of the PSI-MS controlled vocabulary in mzML
Structs
- A CURIE is a namespace + accession identifier
- A controlled vocabulary or user parameter
- A statically allocate-able or non-owned data version of
Param
Enums
- Anything that can be converted into an accession code portion of a
CURIE - Controlled vocabularies used in mass spectrometry data files
- Units that a term’s value might have
- An owned parameter value that may be a string, a number, or empty. It is intended to be paired with the
ParamValuetrait. - A borrowed parameter value that may be a string, a number, or empty. It is intended to be paired with the
ParamValuetrait.
Traits
- Describe a controlled vocabulary parameter or a user-defined parameter
- Access a parameter’s value, with specific coercion rules and eager type conversion.