Struct mzdata::spectrum::SpectrumGroup
source · pub struct SpectrumGroup<C = CentroidPeak, D = DeconvolutedPeak, S = MultiLayerSpectrum<C, D>>{
pub precursor: Option<S>,
pub products: Vec<S>,
/* private fields */
}Expand description
A pairing of an optional MS1 spectrum with all its associated MSn spectra.
Fields
precursor: Option<S>The MS1 spectrum of a group. This may be absent when the source does not contain any MS1 spectra
products: Vec<S>The collection of related MSn spectra. If MSn for n > 2 is used, all levels are present in this collection, though there is no ordering guarantee.
Implementations
sourceimpl<'a, C, D, S> SpectrumGroup<C, D, S>
impl<'a, C, D, S> SpectrumGroup<C, D, S>
pub fn iter(&'a self) -> SpectrumGroupIter<'a, C, D, S> ⓘ